.. include:: references.txt

.. image:: _static/gammapy_banner.png
    :width: 500px
    :class: only-light
    :align: center

.. image:: _static/gammapy_banner_white.png
    :width: 500px
    :class: only-dark
    :align: center

|

Gammapy
-------
**Date**: |today| **Version**: |version|

**Useful links**:
`Web page <https://gammapy.org>`__ |
`Recipes <https://gammapy.github.io/gammapy-recipes>`__  |
`Discussions <https://github.com/gammapy/gammapy/discussions>`__ |
`Acknowledging <https://gammapy.org/acknowledging.html>`__ |
`Contact <https://gammapy.org/contact.html>`__


Gammapy is a community-developed, open-source Python package for gamma-ray
astronomy built on Numpy, Scipy and Astropy. **It is the core library for the** `CTAO`_ **Science Tools**
but can also be used to analyse data from existing imaging atmospheric Cherenkov telescopes
(IACTs), such as `H.E.S.S.`_, `MAGIC`_ and `VERITAS`_. It also provides some support
for `Fermi-LAT`_ and `HAWC`_ data analysis.


.. grid:: 1 2 2 2
   :gutter: 2

   .. grid-item-card::
      :text-align: center
      :columns: 12 6 6 6
      :shadow: md

      :octicon:`rocket;4em`

      **Getting started**

      New to *Gammapy*? Check out the getting started documents. They contain information
      on how to install and start using *Gammapy* on your local desktop computer.

      +++

      .. button-ref:: getting-started
         :ref-type: ref
         :click-parent:
         :color: secondary
         :expand:

         To the quickstart docs

   .. grid-item-card::
      :text-align: center
      :columns: 12 6 6 6
      :shadow: md

      :octicon:`book;4em`

      **User guide**

      The user guide provides in-depth information on the
      key concepts of *Gammapy* with useful background information and explanation,
      as well as tutorials in the form of Jupyter notebooks.

      +++

      .. button-ref:: user_guide
         :ref-type: ref
         :click-parent:
         :color: secondary
         :expand:

         To the user guide

   .. grid-item-card::
      :text-align: center
      :columns: 12 12 12 12
      :shadow: md

      :octicon:`comment-discussion;4em`

      **Community & support**

      Need help? Want to connect with other users and developers?

      +++

      .. button-link:: https://gammapy.slack.com/join/signup#/domain-signup
         :color: secondary

         Join the chat on Slack

      .. button-link:: https://github.com/gammapy/gammapy/issues
         :color: secondary

         Report an issue

   .. grid-item-card::
      :text-align: center
      :columns: 12 6 6 6
      :shadow: md

      :octicon:`database;4em`

      **API reference**

      The reference guide contains a detailed description of
      the *Gammapy* API. The reference describes how the methods work and which parameters can
      be used. It assumes that you have an understanding of the key concepts.

      +++

      .. button-ref:: api-ref
         :ref-type: ref
         :click-parent:
         :color: secondary
         :expand:

         To the reference guide

   .. grid-item-card::
      :text-align: center
      :columns: 12 6 6 6
      :shadow: md

      :octicon:`tools;4em`

      **Developer guide**

      Saw a typo in the documentation? Want to improve
      existing functionalities? The contributing guidelines will guide
      you through the process of improving *Gammapy*.

      +++

      .. button-ref:: dev_intro
         :ref-type: ref
         :click-parent:
         :color: secondary
         :expand:

         To the developer guide



.. toctree::
    :titlesonly:
    :hidden:

    getting-started/index
    user-guide/index
    tutorials/index
    api-reference/index
    development/index
    release-notes/index
